Attribute

Struct Attribute 

pub struct Attribute<T>
where T: ?Sized,
{ pub att_type: AttUuid, pub handle: Handle, pub value: T, }
An ATT server attribute

Fields

att_type: AttUuid

The type of the attribute as a UUID16, EG “Primary Service” or “Anaerobic Heart Rate Lower Limit”

handle: Handle

Unique server-side identifer for attribute

value: T

Attribute values can be any fixed length or variable length octet array, which if too large can be sent across multiple PDUs

Implementations

Source

impl<T: AsRef<[u8]>> Attribute<T>

pub fn new(att_type: AttUuid, handle: Handle, value: T) -> Self

Creates a new attribute.

pub fn value(&self) -> &[u8]

Retrieves the attribute’s value as a slice.

pub fn set_value(&mut self, value: T)

Overrides the previously set attribute’s value.