Cmd

Struct Cmd 

pub struct Cmd {
    pub radio: RadioCmd,
    pub next_update: NextUpdate,
    pub queued_work: bool,
}
Command returned by the Link-Layer to the user.

Specifies how the radio should be configured and when/if to call LinkLayer::update again.

Fields

radio: RadioCmd

Radio configuration request.

next_update: NextUpdate

Time until LinkLayer::update should be called.

If this is None, update doesn’t need to be called because the Link-Layer is in Standby state.

queued_work: bool

Whether the Link-Layer code has enqueued more work into the packet queue.

If this is true, the caller needs to ensure that the queue is drained and processed by calling the Responder. The apps idle loop might unconditionally do that, in which case checking this flag is not necessary.