pub struct Attribute<T>where
T: ?Sized,{
pub att_type: AttUuid,
pub handle: Handle,
pub value: T,
}Expand description
An ATT server attribute
Fields
att_type: AttUuidThe type of the attribute as a UUID16, EG “Primary Service” or “Anaerobic Heart Rate Lower Limit”
handle: HandleUnique server-side identifer for attribute
value: TAttribute values can be any fixed length or variable length octet array, which if too large can be sent across multiple PDUs
Implementations